@@ -2,11 +2,10 @@ import math
 import pytest
 
 np = pytest.importorskip("numpy")
-scipy = pytest.importorskip("scipy")
+pytest.importorskip("scipy")
 
 
 import networkx as nx
-from networkx.testing import almost_equal
 
 
 class TestEigenvectorCentrality:
@@ -17,15 +16,15 @@ class TestEigenvectorCentrality:
         v = math.sqrt(1 / 5.0)
         b_answer = dict.fromkeys(G, v)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n])
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-7)
         nstart = {n: 1 for n in G}
         b = nx.eigenvector_centrality(G, nstart=nstart)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n])
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-7)
 
         b = nx.eigenvector_centrality_numpy(G)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n], places=3)
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-3)
 
     def test_P3(self):
         """Eigenvector centrality: P3"""
@@ -33,10 +32,10 @@ class TestEigenvectorCentrality:
         b_answer = {0: 0.5, 1: 0.7071, 2: 0.5}
         b = nx.eigenvector_centrality_numpy(G)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n], places=4)
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-4)
         b = nx.eigenvector_centrality(G)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n], places=4)
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-4)
 
     def test_P3_unweighted(self):
         """Eigenvector centrality: P3"""
@@ -44,7 +43,7 @@ class TestEigenvectorCentrality:
         b_answer = {0: 0.5, 1: 0.7071, 2: 0.5}
         b = nx.eigenvector_centrality_numpy(G, weight=None)
         for n in sorted(G):
-            assert almost_equal(b[n], b_answer[n], places=4)
+            assert b[n] == pytest.approx(b_answer[n], abs=1e-4)
 
     def test_maxiter(self):
         with pytest.raises(nx.PowerIterationFailedConvergence):
@@ -129,25 +128,25 @@ class TestEigenvectorCentralityDirected:
         G = self.G
         p = nx.eigenvector_centrality(G)
         for (a, b) in zip(list(p.values()), self.G.evc):
-            assert almost_equal(a, b, places=4)
+            assert a == pytest.approx(b, abs=1e-4)
 
     def test_eigenvector_centrality_weighted_numpy(self):
         G = self.G
         p = nx.eigenvector_centrality_numpy(G)
         for (a, b) in zip(list(p.values()), self.G.evc):
-            assert almost_equal(a, b)
+            assert a == pytest.approx(b, abs=1e-7)
 
     def test_eigenvector_centrality_unweighted(self):
         G = self.H
         p = nx.eigenvector_centrality(G)
         for (a, b) in zip(list(p.values()), self.G.evc):
-            assert almost_equal(a, b, places=4)
+            assert a == pytest.approx(b, abs=1e-4)
 
     def test_eigenvector_centrality_unweighted_numpy(self):
         G = self.H
         p = nx.eigenvector_centrality_numpy(G)
         for (a, b) in zip(list(p.values()), self.G.evc):
-            assert almost_equal(a, b)
+            assert a == pytest.approx(b, abs=1e-7)
 
 
 class TestEigenvectorCentralityExceptions:
